@@ -13,6 +13,7 @@ from copy import deepcopy
 from soursop import sstrajectory, ssprotein
 from soursop.ssexceptions import SSException
 from soursop.configs import DEBUGGING
+from contextlib import contextmanager
 
 
 def test_contacts_special(NTL9_CP):
@@ -91,11 +92,11 @@ def test_code_coverage(NTL9_CP):
 
 
     a = NTL9_CP.get_inter_residue_COM_distance(10,30)
-    a = NTL9_CP.get_inter_residue_COM_distance(10,30, stride=2)
+    a = NTL9_CP.get_inter_residue_COM_distance(10,30)
 
 
     a = NTL9_CP.get_inter_residue_COM_vector(10,30)
-    a = NTL9_CP.get_inter_residue_COM_vector(10,30, stride=2)
+    a = NTL9_CP.get_inter_residue_COM_vector(10,30)
 
 
     a = NTL9_CP.get_inter_residue_atomic_distance(2,10)
@@ -108,6 +109,8 @@ def test_get_radius_of_gyration(GS6_CP):
     assert len(GS6_CP.get_radius_of_gyration()) == 5
     assert abs(GS6_CP.get_radius_of_gyration()[0] - 5.728453763896514) < 0.0001
     assert abs(GS6_CP.get_radius_of_gyration(R1=1,R2=3)[0] - 2.8815625777553278) < 0.0001
+    assert GS6_CP.get_radius_of_gyration(R1=0,R2=7)[0]  == GS6_CP.get_radius_of_gyration()[0]
+
 
 def test_get_t(GS6_CP):
 
@@ -190,13 +193,22 @@ def test_get_distance_map(GS6_CO):
         assert np.allclose(distance_map, np.triu(distance_map)) is True
 
 
-
 def test_get_hydrodynamic_radius(GS6_CO):
 
     CP = GS6_CO.proteinTrajectoryList[0]
     rh = CP.get_hydrodynamic_radius()
     assert (11.840569781179006 - rh[0]) < 0.001
 
+def test_get_molecular_volume(NTL9_CO):
+
+    CP = NTL9_CO.proteinTrajectoryList[0]
+    mol_vol = CP.get_molecular_volume()
+    assert len(mol_vol) == 10
+    assert mol_vol[0] - 20839.78797511 < 0.0000001
+    assert np.mean(mol_vol) - 24064.633461433674 < 0.0000001
+
+
+
 
 # ====
 def test_init_from_trajectory(GS6_CO, NTL9_CO, GS6_CP, NTL9_CP):
@@ -585,7 +597,7 @@ def test_get_angle_decay_return_all_pairs(GS6_CP, NTL9_CP):
         # check this has been calculated correctly  -we expect all_pairs
         # to be a dictionary that reports on every unique inter-residue pair
         assert len(all_pairs) == np.sum(list(range(len(return_matrix), 0, -1)))
-        
+
 
 
 def test_get_angle_decay_no_return_all_pairs(GS6_CP, NTL9_CP):
@@ -631,8 +643,9 @@ def test_get_contact_map_weights_sidechain_heavy(GS6_CP, NTL9_CP):
         weights = [default_weight for frame in range(protein.n_frames)]
         normalized_weights = [w/protein.n_frames for w in weights]
 
-        # note in a previous v
-        protein.get_contact_map(mode=mode, weights=normalized_weights)  # the other options have been tested
+        # both proteins have 'GLY', which will fail here as it lacks a sidechain
+        with pytest.raises(SSException):
+            protein.get_contact_map(mode=mode, weights=normalized_weights)  # the other options have been tested
 
     # this should fail with an SSException
     mode = 'invalid-mode'
@@ -643,8 +656,8 @@ def test_get_contact_map_weights_sidechain_heavy(GS6_CP, NTL9_CP):
 
         with pytest.raises(SSException):
             protein.get_contact_map(mode=mode, weights=normalized_weights)  # the other options have been tested
-        
-        
+
+
 
 
 # SSProtein.get_sidechain_alignment_angle
@@ -660,9 +673,18 @@ def test_get_sidechain_alignment_angle_unsupported_angle(GS6_CP, NTL9_CP):
             protein.get_sidechain_alignment_angle(R1, R2, sidechain_atom_2='invalid_atom')
 
 
+# From: https://stackoverflow.com/a/42327075
+@contextmanager
+def not_raises(exception):
+    try:
+        yield
+    except exception:
+        raise pytest.fail("DID RAISE {0}".format(exception))
+
+
 def test_get_sidechain_alignment_angle_successful_random(GS6_CP, NTL9_CP):
     proteins = [GS6_CP, NTL9_CP]
-    for protein in [NTL9_CP]:
+    for protein in proteins:
         residue_indices = list(range(protein.n_residues))
         mid_point = (protein.n_residues//2) - 1
         lower = residue_indices[1:mid_point]
@@ -675,25 +697,48 @@ def test_get_sidechain_alignment_angle_successful_random(GS6_CP, NTL9_CP):
         r1 = random.choice(upper)
         r2 = random.choice(lower)
 
-        alignment = protein.get_sidechain_alignment_angle(r1, r2)
-        assert len(alignment) == protein.n_frames
+        # ensure that our residues do not reference GLY
+        # otherwise this test will fail. Since we only
+        # wish to test successful alignments, we skip over
+        # these residues.
+        df, indices = protein.topology.to_dataframe()
+        error_residue_indices = list()
+        error_residues = 'ACE,GLY,NME'.split(',')
 
-    for protein in [GS6_CP]:
-        residue_indices = list(range(protein.n_residues))
-        mid_point = (protein.n_residues//2) - 1
-        lower = residue_indices[1:mid_point]
-        upper = residue_indices[mid_point+1:-1]
+        # convert from ids to indices (subtract 1)
+        for residue_name in error_residues:
+            error_residue_indices += list(sorted(set([i-1 for i in df[df['resName'] == residue_name]['resSeq']])))
 
-        # Shuffle to ensure that the indices chosen, whilst random
-        # are always where R1 > R2.
-        random.shuffle(lower)
-        random.shuffle(upper)
-        r1 = random.choice(upper)
-        r2 = random.choice(lower)
+        reset_loop = False
+        for resid in [r1, r2]:
+            if resid in error_residue_indices:
+                reset_loop = True
+                break
+
+        if reset_loop:
+            continue
+
+        with not_raises(SSException):
+            alignment = protein.get_sidechain_alignment_angle(r1, r2)
+
+
+def test_get_sidechain_alignment_angle_failing_random(GS6_CP, NTL9_CP):
+    proteins = [GS6_CP, NTL9_CP]
+    for protein in proteins:
+        # Identify the indices of the residues that will fail.
+        df, indices = protein.topology.to_dataframe()
+        error_residue_indices = list()
+        error_residues = 'ACE,GLY,NME'.split(',')
+
+        # convert from ids to indices (subtract 1)
+        for residue_name in error_residues:
+            error_residue_indices += list(sorted(set([i-1 for i in df[df['resName'] == residue_name]['resSeq']])))
+
+        r1 = random.choice(error_residue_indices)
+        r2 = random.choice(error_residue_indices)
 
         with pytest.raises(SSException):
             alignment = protein.get_sidechain_alignment_angle(r1, r2)
-        
 
 
 def test_get_sidechain_alignment_angle_invalid_r1(GS6_CP, NTL9_CP):
@@ -811,7 +856,7 @@ def test_get_angles_1(GS6_CP, NTL9_CP):
     assert len(GS6_CP.get_angles('phi')[0]) == 6
     assert GS6_CP.get_angles('phi')[0][0][0] == 'ACE1-C'
     assert GS6_CP.get_angles('phi')[0][5][3] == 'SER7-C'
-    assert np.isclose(GS6_CP.get_angles('phi')[1][5][3], -147.67358) 
+    assert np.isclose(GS6_CP.get_angles('phi')[1][5][3], -147.67358)
     assert np.isclose(GS6_CP.get_angles('phi')[1][5][0], -126.707436)
     assert np.isclose(GS6_CP.get_angles('phi')[1][0][0], -157.64288)
     assert np.isclose(GS6_CP.get_angles('psi')[1][0][0] , -41.66139)
@@ -832,3 +877,42 @@ def test_get_angles_1(GS6_CP, NTL9_CP):
     assert len(NTL9_CP.get_angles('chi3')[0]) == 21
     assert len(NTL9_CP.get_angles('chi4')[0]) == 12
     assert len(NTL9_CP.get_angles('chi5')[0]) == 1
+
+
+
+def test_get_inter_residue_COM_vector(GS6_CP, NTL9_CP):
+    """
+    Test that the inter-residue COM vector matches the distances
+    calculated using inter_residue_COM_distance.
+
+    """
+
+    
+    com_distances = GS6_CP.get_inter_residue_COM_distance(0,5) 
+    com_distances_manually = np.sqrt(np.sum(np.square(GS6_CP.get_inter_residue_COM_vector(0,5)),1))
+    assert np.sum(com_distances - com_distances_manually) < 0.001
+
+
+    com_distances = NTL9_CP.get_inter_residue_COM_distance(0,25) 
+    com_distances_manually = np.sqrt(np.sum(np.square(NTL9_CP.get_inter_residue_COM_vector(0, 25)),1))
+    assert np.sum(com_distances - com_distances_manually) < 0.001
+
+
+
+def test_get_center_of_mass(GS6_CP, NTL9_CP):
+
+    
+    molecular_com = GS6_CP.get_center_of_mass()
+    assert(len(molecular_com)) == GS6_CP.n_frames
+    
+    # compute COM of residues 0 and 1
+    R0_com = GS6_CP.get_center_of_mass(0,0)
+    R5_com = GS6_CP.get_center_of_mass(5,5)
+
+    com_distances_from_center_of_mass = np.sqrt(np.sum(np.square(R0_com - R5_com),1))
+    com_distances_manually = np.sqrt(np.sum(np.square(GS6_CP.get_inter_residue_COM_vector(0,5)),1))
+    com_distances = GS6_CP.get_inter_residue_COM_distance(0,5) 
+
+    assert np.sum(com_distances_manually - com_distances_from_center_of_mass) == 0
+    assert np.sum(com_distances - com_distances_from_center_of_mass) == 0
+    
